import {getAllRoleList} from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import {h} from "vue";
import {Input, Select, Tag} from "ant-design-vue";
import { Switch } from 'ant-design-vue';
import {useMessage} from "@/hooks/web/useMessage";
import {changeFlagApi} from "@/api/system/user/user";
import {DescItem} from "@/components/Description";
import {uploadApi} from "@/api/sys/upload"; // 引入开关组件
type CheckedType = boolean | string | number;

/**主页面列表 表头*/
export const columns: BasicColumn[] = [
  {
    title: '标准中文名称',
    dataIndex: 'standardChineseName',
    width: 150,
  },
  {
    title: '标准编号',
    dataIndex: 'standardCode',
    width: 150,
  },
  {
    title: '引用标准',
    dataIndex: 'referenceStandard',
    width: 150,
    slots: { customRender: 'referenceStandard' },
  },
  {
    title: '业务定义',
    dataIndex: 'businessDefinition',
    width: 150,
  },
  {
    title: '发布状态',
    dataIndex: 'publishStatus',
    width: 150,
  },
  {
    title: '权属工作组',
    dataIndex: 'holderGroup',
    width: 150,
  },
];
/**主页面搜索 表单*/
export const searchFormSchema: FormSchema[] = [
  {
    field: 'standardCode',
    label: '标准编号',
    component: 'Input',
    componentProps: {
      placeholder: '请输入标准编号',
    },
    colProps: { span: 6 },
  },
  {
    field: 'standardChineseName',
    label: '标准中文名称',
    component: 'Input',
    componentProps: {
      placeholder: '请输入标准中文名称',
    },
    colProps: { span: 6 },
  },
  {
    field: 'businessDefinition',
    label: '业务定义',
    component: 'Input',
    componentProps: {
      placeholder: '请输入业务定义',
    },
    colProps: { span: 6 },
  },
];
/**导入关联关系 表单*/
export const importRelativeFormSchema: FormSchema[] = [
  {
    field: 'file',
    component: 'Upload',
    label: '导入文件选择',
    rules: [{ required: true, message: '请选择上传文件' }],
    componentProps: {
      api: uploadApi,
    },
    labelWidth: 150,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'agreement',
    component: 'RadioGroup',
    label: '关联关系重名',
    colProps: { lg: 24, md: 24 },
    labelWidth: 150,
    componentProps: {
      defaultValue:'1',
      options: [
        {
          label: '全部放弃',
          value: '1',
        },
        {
          label: '全部替换',
          value: '2',
        },
      ],
    },
  },
];
/**导入数据标准 表单*/
export const importDataStandardsFormSchema: FormSchema[] = [
  {
    field: 'file',
    component: 'Upload',
    label: '导入文件选择',
    componentProps: {
      api: uploadApi,
    },
    labelWidth: 150,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'agreement',
    component: 'RadioGroup',
    label: '标准重名',
    colProps: { lg: 24, md: 24 },
    labelWidth: 150,
    componentProps: {
      defaultValue:'1',
      options: [
        {
          label: '全部放弃',
          value: '1',
        },
        {
          label: '全部替换',
          value: '2',
        },
        {
          label: '自动重命名',
          value: '3',
        },
      ],
    },
  },
];
/**移动 表单*/
export const moveFormSchema: any[] = [
  {
    field: 'treeId',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'standardChineseName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
]
/**重命名 表单*/
export const resetNameFormSchema: FormSchema[] = [
  {
    field: 'standardChineseName',
    label: '标准中文名称',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入标准中文名称',
      },
    ],
    componentProps: {
      placeholder: '请输入标准中文名称',
    },
    colProps: { lg: 24, md: 24 },
  },
];
/**新建标准分类 表单*/
export const createBasicTypeFormSchema: FormSchema[] = [
  {
    field: 'standardsTree',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'standardChineseName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  {
    field: 'standardsTypeName',
    label: '标准分类名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入标准分类名称',
      },
    ],
    componentProps: {
      placeholder: '请输入标准分类名称',
    },
  },
  {
    field: 'standardsTypeDescription',
    label: '标准分类描述',
    component: 'InputTextArea',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入标准分类描述',
      },
    ],
    componentProps: {
      placeholder: '请输入标准分类描述',
    },
  },
  {
    field: 'ModelTree',
    label: '关联元模型',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'standardChineseName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  {
    field: 'permissionMode',
    label: '权限模式',
    component: 'RadioGroup',
    defaultValue: '1',
    componentProps: {
      options: [
        { label: '本级定义', value: '1' },
        { label: '资源自定义', value: '0' },
      ],
    },
    required: true,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'username',
    label: '权属工作组',
    component: 'Select',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      options:[
        {
          label: '默认工作组',
          value: '1',
        },
        {
          label: '个人工作组',
          value: '2',
        },
        {
          label: '共享工作组',
          value: '3',
        },
      ]
    },
    rules: [
      {
        required: true,
        message: '请输入权属工作组',
      },
    ],
  },
];
/**新建基础标准 表单*/
export const createBasicStandardsFormSchema: FormSchema[] = [
  {
    field: 'standardsTree',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'standardChineseName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  {
    field: 'standardsName',
    label: '标准名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入标准名称',
      },
    ],
    componentProps: {
      placeholder: '请输入标准名称',
    },
  },
  {
    field: 'standardsTypeName',
    label: '标准类型',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    defaultValue: '公共代码',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
    },
    rules: [
      {
        required: true,
        message: '请输入标准类型',
      },
    ],
  },
  {
    field: 'permissionMode',
    label: '目录权属模式',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    defaultValue: '本级定义',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
    },
    rules: [
      {
        required: true,
        message: '请输入目录权属模式',
      },
    ],
  },
  {
    field: 'username',
    label: '权属工作组',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    defaultValue: '-',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
    },
    rules: [
      {
        required: true,
        message: '请输入权属工作组',
      },
    ],
  },
];

/**基础公共代码表单*/
export const detailSchema: FormSchema[] = [
  {
    field: '',
    label: '属性',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'standardPath',
    label: '标准路径',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准路径',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
  {
    field: 'standardNumber',
    label: '标准编号',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准编号',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入标准编号',
    },
  },
  {
    field: 'standardChineseName',
    label: '标准中文名称',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准中文名称',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入标准中文名称',
    },
  },
  {
    field: 'standardSource',
    label: '标准来源',
    component: 'Select',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请选择标准来源',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      disabled: true,
      options:[
        {
          label:'国际标准',
          value:'1'
        },
        {
          label:'国家标准',
          value:'2'
        },
        {
          label:'行业标准',
          value:'3'
        },
        {
          label:'行业实践',
          value:'4'
        },
        {
          label:'监管规定(人行)',
          value:'5'
        },
        {
          label:'监管规定(银监)',
          value:'6'
        },
        {
          label:'行内发文',
          value:'7'
        },
        {
          label:'行内协商一致',
          value:'8'
        },
      ],
      placeholder: '请选择标准来源',
    },
  },
  {
    field: 'businessDefinition',
    label: '业务定义',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入业务定义',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
  {
    field: 'definitionBasis',
    label: '定义依据',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入定义依据',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
];
/**详情页列表 表头*/
export const detailColumns: BasicColumn[] = [
  {
    title: '代码值',
    dataIndex: 'codeValue',
    width: 150
  },
  {
    title: '代码含义',
    dataIndex: 'codeMeaning',
    width: 150
  },
  {
    title: '说明',
    dataIndex: 'description',
    width: 150
  },
  {
    title: '修改人',
    dataIndex: 'updateBy',
    width: 150
  },
  {
    title: '修改时间',
    dataIndex: 'updateDate',
    width: 150
  },
  {
    title: '源系统码值',
    dataIndex: 'sourceSystemCodeValue',
    width: 150
  }
];
/**详情页列表 表单*/
export const detailFormSchema: FormSchema[] = [
  {
    field: 'codeValue',
    label: '代码值',
    component: 'Input',
    componentProps: {
      placeholder: '请输入代码值',
    },
    colProps: { span: 6 },
  },
  {
    field: 'codeMeaning',
    label: '代码含义',
    component: 'Input',
    componentProps: {
      placeholder: '请输入代码含义',
    },
    colProps: { span: 6 },
  },
  {
    field: 'sourceSystemCodeValue',
    label: '源系统码值',
    component: 'Input',
    componentProps: {
      placeholder: '请输入源系统码值',
    },
    colProps: { span: 6 },
  },
];
/**编辑公共代码 表单1*/
export const editStandardsDetailFormSchema: FormSchema[] = [
  {
    field: '',
    label: '属性',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'standardPath',
    label: '标准路径',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准路径',
      },
    ],
    componentProps: {
      placeholder: '-',
    },
  },
  {
    field: 'standardNumber',
    label: '标准编号',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准编号',
      },
    ],
    componentProps: {
      placeholder: '请输入标准编号',
    },
  },
  {
    field: 'standardChineseName',
    label: '标准中文名称',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准中文名称',
      },
    ],
    componentProps: {
      placeholder: '请输入标准中文名称',
    },
  },
  {
    field: 'standardSource',
    label: '标准来源',
    component: 'Select',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请选择标准来源',
      },
    ],
    componentProps: {
      options:[
        {
          label:'国际标准',
          value:'1'
        },
        {
          label:'国家标准',
          value:'2'
        },
        {
          label:'行业标准',
          value:'3'
        },
        {
          label:'行业实践',
          value:'4'
        },
        {
          label:'监管规定(人行)',
          value:'5'
        },
        {
          label:'监管规定(银监)',
          value:'6'
        },
        {
          label:'行内发文',
          value:'7'
        },
        {
          label:'行内协商一致',
          value:'8'
        },
      ],
      placeholder: '请选择标准来源',
    },
  },
  {
    field: 'businessDefinition',
    label: '业务定义',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入业务定义',
      },
    ],
    componentProps: {
      placeholder: '-',
    },
  },
  {
    field: 'definitionBasis',
    label: '定义依据',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入定义依据',
      },
    ],
    componentProps: {
      placeholder: '-',
    },
  },
];
/**编辑公共代码 表单2*/
export const addValueFormSchema: FormSchema[] = [
  {
    field: 'codeValue',
    label: '代码值',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: '请输入代码值',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'codeMeaning',
    label: '代码含义',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: '请输入代码含义',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'description',
    label: '说明',
    component: 'Input',
    componentProps: {
      placeholder: '请输入说明',
    },
    colProps: { lg: 24, md: 24 },
  },
];
/**编辑公共代码 表单3*/
export const addValueSearchSchema: FormSchema[] = [
  {
    field: 'sourceSystem',
    label: '源系统',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: '请输入源系统',
    },
    colProps: { span: 8 },
  },
  {
    field: 'sourceSystemCodeValue',
    label: '源系统码值',
    component: 'Input',
    componentProps: {
      placeholder: '请输入源系统码值',
    },
    colProps: { span: 8 },
  },
];
/**编辑公共代码 表单4*/
export const editPublicCodeSchema: FormSchema[] = [
  {
    field: 'codeValue',
    label: '代码值',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: '请输入代码值',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'codeMeaning',
    label: '代码含义',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: '请输入代码含义',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'description',
    label: '说明',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: '请输入说明',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'sourceSystemCodeValue',
    label: '源系统码值',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: '请输入源系统码值',
    },
    colProps: { lg: 24, md: 24 },
  },
];
/**详情公共代码 表单5*/
export const detailPublicCodeSchema: FormSchema[] = [
  {
    field: 'codeValue',
    label: '代码值',
    component: 'Input',
    required: true,
    componentProps: {
      style: {
        border: 'none',
      },
      readonly: true,
      placeholder: '请输入代码值',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'codeMeaning',
    label: '代码含义',
    component: 'Input',
    required: true,
    componentProps: {
      style: {
        border: 'none',
      },
      readonly: true,
      placeholder: '请输入代码含义',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'description',
    label: '说明',
    component: 'Input',
    required: true,
    componentProps: {
      style: {
        border: 'none',
      },
      readonly: true,
      placeholder: '请输入说明',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'sourceSystemCodeValue',
    label: '源系统码值',
    component: 'Input',
    required: true,
    componentProps: {
      style: {
        border: 'none',
      },
      readonly: true,
      placeholder: '请输入源系统码值',
    },
    colProps: { lg: 24, md: 24 },
  },
];
/**编辑公共代码 列表表头*/
export const addValueColumns: BasicColumn[] = [
  {
    title: '源系统',
    dataIndex: 'sourceSystem',
    width: 150
  },
  {
    title: '源系统码值',
    dataIndex: 'sourceSystemCodeValue',
    width: 150
  },
];


/**版本对比 表单*/
export const contrastSchema: FormSchema[] = [
  {
    field: '',
    label: '属性',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'standardPath',
    label: '标准路径',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入标准路径',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入标准路径',
    },
  },
  {
    field: 'standardNumber',
    label: '标准编号',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入标准编号',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入标准编号',
    },
  },
  {
    field: 'standardChineseName',
    label: '标准中文名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入标准中文名称',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入标准中文名称',
    },
  },
  {
    field: 'standardSource',
    label: '标准来源',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入标准来源',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入标准来源',
    },
    slot: 'standardSource',
  },
  {
    field: 'businessDefinition',
    label: '业务定义',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入业务定义',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入业务定义',
    },
  },
  {
    field: 'definitionBasis',
    label: '定义依据',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入定义依据',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入定义依据',
    },
  },
];
/**版本对比 表单2*/
export const contrastSchema2: FormSchema[] = [
  {
    field: 'checked',
    component: 'Checkbox',
    label: '只看差异代码',
    colProps: { lg: 24, md: 24 },
    renderComponentContent: '',
  },
  {
    field: 'order',
    label: '排序',
    component: 'Select',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      options:[
        {
          label: '代码值升序',
          value: '1',
        },
        {
          label: '代码值降序',
          value: '2',
        },
      ]
    },
    rules: [
      {
        required: true,
        message: '请选择排序',
      },
    ],
  },
];
/**版本对比 列表*/
export const contrastTableColumns: BasicColumn[] = [
  {
    title: '代码值',
    dataIndex: 'codeValue',
    width: 150
  },
  {
    title: '代码含义',
    dataIndex: 'codeMeaning',
    width: 150
  },
  {
    title: '说明',
    dataIndex: 'description',
    width: 150
  },
  {
    title: '修改人',
    dataIndex: 'updateBy',
    width: 150
  },
  {
    title: '修改时间',
    dataIndex: 'updateDate',
    width: 150
  },
];


/**关联关系 表头3*/
export const relatedRelationshipColumns3: BasicColumn[] = [
  {
    title: '标准名称',
    dataIndex: 'standardName',
    width: 150,
    slots: { customRender: 'standardName' },
  },
  {
    title: '标准编号',
    dataIndex: 'standardNumber',
    width: 150,
  },
  {
    title: '路径',
    dataIndex: 'path',
    width: 150,
  },
  {
    title: '关联描述',
    dataIndex: 'associationDescription',
    width: 150,
  },
  {
    title: '关联关系',
    dataIndex: 'associationRelation',
    width: 150,
  },
  {
    title: '关联时间',
    dataIndex: 'associationTime',
    width: 150,
  },
  {
    title: '操作用户',
    dataIndex: 'operatorUser',
    width: 150,
  },
];
/**关联关系-关联基础标准 表单*/
export const relatedBasicStandardsSchema: any[] = [
  {
    field: 'basicStandardsTree',
    label: '关联基础标准',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'standardChineseName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  {
    field: 'relatedRelationship',
    label: '关联关系',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入关联关系',
      },
    ],
    componentProps: {
      placeholder: '请输入关联关系',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'relatedDescription',
    label: '关联描述',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入关联描述',
      },
    ],
    componentProps: {
      placeholder: '请输入关联描述',
    },
    colProps: { lg: 24, md: 24 },
  },
]

