import {getAllRoleList} from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import {h} from "vue";
import {Tag} from "ant-design-vue";
import { Switch } from 'ant-design-vue';
import {useMessage} from "@/hooks/web/useMessage";
import {changeFlagApi} from "@/api/system/user/user";
import {relatedQualityColumns} from "@/views/dataStandards/basicStandards/basicStandards.data"; // 引入开关组件
type CheckedType = boolean | string | number;

/**版本管理列表 表头*/
export const versionColumns: BasicColumn[] = [
  {
    title: '版本ID',
    dataIndex: 'versionId',
    width: 150,
  },
  {
    title: '版本名称',
    dataIndex: 'versionName',
    width: 150,
  },
  {
    title: '提交人',
    dataIndex: 'submitBy',
    width: 150,
  },
  {
    title: '提交时间',
    dataIndex: 'submitDate',
    width: 150,
  },
  {
    title: '备注',
    dataIndex: 'remarks',
    width: 150,
  },
];

/**版本管理弹出框 搜索表头*/
export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '',
    component: 'Input',
    componentProps: {
      placeholder: '请输入版本名称',
    },
    colProps: { span: 7 },
  },
];

/**主页面树/列表 数据*/
export const TreeData: any[] = [
  {
    "businessId": 100,
    "standardChineseName": "公共代码",
    "anotherName": "公共代码",
    "parentId": 0,
    "businessDefinition": "公共代码",
    "location": "/公共代码",
    "publishStatus": "已发布",
    "holderGroup": "默认工作组",
    "standardCode": "BAS000001",
    "referenceStandard":[
      { icon: '😂', text: '数据源1' },
      { icon: '🔍', text: '数据源2' },
    ],
    "createDate": "2024-10-24 10:04:04",
    "updateDate": "2024-10-24 10:04:04",
    "icon": "ant-design:partition-outlined",
    "businessAttribute": "通用",
    "standardNumber": "BAS-001",
    "standardEnglishName": "Basic Standard",
    "standardAlias": "Basic Standard",
    "standardSource": "1",
    "definitionBasis": "相关法律法规",
    "businessRule": "所有基础标准必须经过审核才能发布。",
    "dataType": "1",
    "tecDataType": "varchar",
    "valueRange": "非空字符串",
    "codeNumber": "CODE-100",
    "adaptability": "1",
    "technicalAttribute": "通用技术属性",
    "dataDisplay": "文本显示",
    "dataPrecision": "无",
    "dataLength": "255",
    "measurementUnit": "无",
    "managementAttribute": "通用管理属性",
    "creator": "张三",
    "updater": "李四",
    "secondaryAuthorityDepartment": "技术部",
    "tertiaryAuthorityDepartment": "研发组",
    "coreSystem": "核心系统A",
    "dataStandardStatus": "有效",
    "expirationDate": "2025-10-24",
    "expirationReason": "无",
    "collaborativeDepartment": "财务部, 市场部",
    standardPath:'/公共代码',
    indicatorCaliber:'销售额-成本/实际成本',
    referenceDocument:'100',
    calculationFormula:'销售额-成本/实际成本',
  },
  {
    "businessId": 101,
    "standardChineseName": "共享工作区",
    "anotherName": "共享工作区",
    "parentId": 100,
    "businessDefinition": "共享工作区",
    "publishStatus": "已发布",
    "ancestors": "0,100",
    "standardCode": "BAS000002",
    "location": "/公共代码/共享工作区",
    "holderGroup": "共享工作区",
    "createDate": "2024-10-24 10:04:04",
    "updateDate": "2024-10-24 10:04:04",
    "icon": "ant-design:folder-open-outlined",
    "businessAttribute": "协作",
    "standardNumber": "BAS-002",
    "standardEnglishName": "Shared Workspace",
    "standardAlias": "Shared Workspace",
    "standardSource": "1",
    "definitionBasis": "用户需求分析",
    "businessRule": "共享工作区内的文件必须定期备份。",
    "dataType": "1",
    "tecDataType": "varchar",
    "valueRange": "非空字符串",
    "codeNumber": "CODE-101",
    "adaptability": "1",
    "technicalAttribute": "通用技术属性",
    "dataDisplay": "文本显示",
    "dataPrecision": "无",
    "dataLength": "255",
    "measurementUnit": "无",
    "managementAttribute": "通用管理属性",
    "creator": "张三",
    "updater": "李四",
    "secondaryAuthorityDepartment": "技术部",
    "tertiaryAuthorityDepartment": "研发组",
    "coreSystem": "核心系统A",
    "dataStandardStatus": "有效",
    "expirationDate": "2025-10-24",
    "expirationReason": "无",
    "collaborativeDepartment": "财务部, 市场部",
    standardPath:'/公共代码/共享工作区',
    indicatorCaliber:'销售额-成本/实际成本',
    referenceDocument:'100',
    calculationFormula:'销售额-成本/实际成本',
  },
  {
    "businessId": 102,
    "standardChineseName": "个人工作区",
    "anotherName": "个人工作区",
    "parentId": 100,
    "publishStatus": "未发布",
    "businessDefinition": "个人工作区",
    "standardCode": "BAS000003",
    "ancestors": "0,100",
    "location": "/公共代码/个人工作区",
    "holderGroup": "个人工作区",
    "createDate": "2024-10-24 10:04:04",
    "updateDate": "2024-10-24 10:04:04",
    "icon": "ant-design:folder-open-outlined",
    "businessAttribute": "个人",
    "standardNumber": "BAS-003",
    "standardEnglishName": "Personal Workspace",
    "standardAlias": "Personal Workspace",
    "standardSource": "1",
    "definitionBasis": "用户需求分析",
    "businessRule": "个人工作区内的文件必须定期清理。",
    "dataType": "1",
    "tecDataType": "varchar",
    "valueRange": "非空字符串",
    "codeNumber": "CODE-102",
    "adaptability": "1",
    "technicalAttribute": "通用技术属性",
    "dataDisplay": "文本显示",
    "dataPrecision": "无",
    "dataLength": "255",
    "measurementUnit": "无",
    "managementAttribute": "通用管理属性",
    "creator": "王五",
    "updater": "赵六",
    "secondaryAuthorityDepartment": "技术部",
    "tertiaryAuthorityDepartment": "运维组",
    "coreSystem": "核心系统B",
    "dataStandardStatus": "1",
    "expirationDate": "2025-10-24",
    "expirationReason": "无",
    "collaborativeDepartment": "人力资源部, 技术部",
    standardPath:'/公共代码/个人工作区',
    indicatorCaliber:'销售额-成本/实际成本',
    referenceDocument:'100',
    calculationFormula:'销售额-成本/实际成本',
  },
  {
    "businessId": 201,
    "standardChineseName": "对外投资出资方式",
    "anotherName": "对外投资出资方式",
    "parentId": 102,
    "publishStatus": "已发布",
    "businessDefinition": "对外投资出资方式",
    "standardCode": "BAS000004",
    "referenceStandard":[
      { icon: '🌐🔍', text: '数据源1' },
    ],
    "ancestors": "0,100,102",
    "location": "/公共代码/个人工作区/对外投资出资方式",
    "holderGroup": "个人工作区",
    "createDate": "2024-10-22 8:04:04",
    "updateDate": "2024-10-22 8:04:04",
    "icon": "ant-design:partition-outlined",
    "businessAttribute": "财务",
    "standardNumber": "BAS-004",
    "standardEnglishName": "Investment Contribution Method",
    "standardAlias": "Investment Contribution Method",
    "standardSource": "国家标准化管理委员会",
    "definitionBasis": "相关法律法规",
    "businessRule": "对外投资的出资方式必须明确记录。",
    "dataType": "1",
    "tecDataType": "varchar",
    "valueRange": "非空字符串",
    "codeNumber": "CODE-201",
    "adaptability": "1",
    "technicalAttribute": "通用技术属性",
    "dataDisplay": "文本显示",
    "dataPrecision": "无",
    "dataLength": "255",
    "measurementUnit": "无",
    "managementAttribute": "通用管理属性",
    "creator": "王五",
    "updater": "赵六",
    "secondaryAuthorityDepartment": "技术部",
    "tertiaryAuthorityDepartment": "运维组",
    "coreSystem": "核心系统B",
    "dataStandardStatus": "有效",
    "expirationDate": "2025-10-24",
    "expirationReason": "无",
    "collaborativeDepartment": "人力资源部, 技术部",
    standardPath:'/公共代码/个人工作区/对外投资出资方式',
    indicatorCaliber:'销售额-成本/实际成本',
    referenceDocument:'100',
    calculationFormula:'销售额-成本/实际成本',
  },
  {
    "referenceStandard":[
      { icon: '🌐🔍', text: '数据源1' },
    ],
    "businessId": 202,
    "standardChineseName": "对外投资控股标志",
    "anotherName": "对外投资控股标志",
    "parentId": 102,
    "publishStatus": "未发布",
    "businessDefinition": "对外投资控股标志",
    "standardCode": "BAS000005",
    "ancestors": "0,100,102",
    "location": "/公共代码/个人工作区/对外投资控股标志",
    "holderGroup": "个人工作区",
    "createDate": "2024-10-22 8:04:04",
    "updateDate": "2024-10-22 8:04:04",
    "icon": "ant-design:partition-outlined",
    "businessAttribute": "财务",
    "standardNumber": "BAS-005",
    "standardEnglishName": "Investment Holding Mark",
    "standardAlias": "Investment Holding Mark",
    "standardSource": "国家标准化管理委员会",
    "definitionBasis": "相关法律法规",
    "businessRule": "对外投资的控股标志必须明确记录。",
    "dataType": "1",
    "tecDataType": "varchar",
    "valueRange": "非空字符串",
    "codeNumber": "CODE-202",
    "adaptability": "1",
    "technicalAttribute": "通用技术属性",
    "dataDisplay": "文本显示",
    "dataPrecision": "无",
    "dataLength": "255",
    "measurementUnit": "无",
    "managementAttribute": "通用管理属性",
    "creator": "王五",
    "updater": "赵六",
    "secondaryAuthorityDepartment": "技术部",
    "tertiaryAuthorityDepartment": "运维组",
    "coreSystem": "核心系统B",
    "dataStandardStatus": "有效",
    "expirationDate": "2025-10-24",
    "expirationReason": "无",
    "collaborativeDepartment": "人力资源部, 技术部",
    standardPath:'/公共代码/个人工作区/对外投资控股标志',
    indicatorCaliber:'销售额-成本/实际成本',
    referenceDocument:'100',
    calculationFormula:'销售额-成本/实际成本',
  },
  {
    "referenceStandard":[
      { icon: '🌐🔍', text: '数据源1' },
    ],
    "businessId": 203,
    "standardChineseName": "对外投资企业证明",
    "anotherName": "对外投资企业证明",
    "parentId": 102,
    "publishStatus": "已发布",
    "businessDefinition": "对外投资企业证明",
    "standardCode": "BAS000006",
    "ancestors": "0,100,102",
    "location": "/公共代码/个人工作区/对外投资企业证明",
    "holderGroup": "个人工作区",
    "createDate": "2024-10-22 8:04:04",
    "updateDate": "2024-10-22 8:04:04",
    "icon": "ant-design:partition-outlined",
    "businessAttribute": "财务",
    "standardNumber": "BAS-006",
    "standardEnglishName": "Investment Company Proof",
    "standardAlias": "Investment Company Proof",
    "standardSource": "国家标准化管理委员会",
    "definitionBasis": "相关法律法规",
    "businessRule": "对外投资的企业证明必须合法有效。",
    "dataType": "1",
    "tecDataType": "varchar",
    "valueRange": "非空字符串",
    "codeNumber": "CODE-203",
    "adaptability": "1",
    "technicalAttribute": "通用技术属性",
    "dataDisplay": "文本显示",
    "dataPrecision": "无",
    "dataLength": "255",
    "measurementUnit": "无",
    "managementAttribute": "通用管理属性",
    "creator": "王五",
    "updater": "赵六",
    "secondaryAuthorityDepartment": "技术部",
    "tertiaryAuthorityDepartment": "运维组",
    "coreSystem": "核心系统B",
    "dataStandardStatus": "有效",
    "expirationDate": "2025-10-24",
    "expirationReason": "无",
    "collaborativeDepartment": "人力资源部, 技术部",
    standardPath:'/公共代码/个人工作区/对外投资企业证明',
    indicatorCaliber:'销售额-成本/实际成本',
    referenceDocument:'100',
    calculationFormula:'销售额-成本/实际成本',
  },
  {
    "referenceStandard":[
      { icon: '🌐🔍', text: '数据源1' },
    ],
    "businessId": 204,
    "standardChineseName": "zy_basic_standard",
    "anotherName": "zy_basic_standard",
    "parentId": 101,
    "publishStatus": "已发布",
    "businessDefinition": "zy_basic_standard",
    "standardCode": "BAS000007",
    "ancestors": "0,100,101",
    "location": "/公共代码/共享工作区/zy_basic_standard",
    "holderGroup": "共享工作区",
    "createDate": "2024-10-22 8:04:04",
    "updateDate": "2024-10-22 8:04:04",
    "icon": "ant-design:partition-outlined",
    "businessAttribute": "通用",
    "standardNumber": "BAS-007",
    "standardEnglishName": "ZY Basic Standard",
    "standardAlias": "ZY Basic Standard",
    "standardSource": "1",
    "definitionBasis": "用户需求分析",
    "businessRule": "所有基本标准必须经过审核才能发布。",
    "dataType": "1",
    "tecDataType": "varchar",
    "valueRange": "非空字符串",
    "codeNumber": "CODE-204",
    "adaptability": "1",
    "technicalAttribute": "通用技术属性",
    "dataDisplay": "文本显示",
    "dataPrecision": "无",
    "dataLength": "255",
    "measurementUnit": "无",
    "managementAttribute": "通用管理属性",
    "creator": "王五",
    "updater": "赵六",
    "secondaryAuthorityDepartment": "技术部",
    "tertiaryAuthorityDepartment": "运维组",
    "coreSystem": "核心系统B",
    "dataStandardStatus": "有效",
    "expirationDate": "2025-10-24",
    "expirationReason": "无",
    "collaborativeDepartment": "人力资源部, 技术部",
    standardPath:'/公共代码/共享工作区/zy_basic_standard',
    indicatorCaliber:'销售额-成本/实际成本',
    referenceDocument:'100',
    calculationFormula:'销售额-成本/实际成本',
  }
];

export const fileData: any[] = [
    {
      "delFlag" : "0",
      "flag" : "1",
      "businessId" : 300,
      "username" : "file1",
      "nickName" : "测试文件流1",
      "name" : "测试文件流1",
      "fileSize": 1024,
      "holder":"admin",
      "createDate": "2024-10-24 10:04:04",
      "updateDate": "2024-10-24 10:04:04",
      "institutionId" : 105,
      "institutionName" : "财务部门",
      "menuList" : [ ]
    },
    {
      "delFlag" : "0",
      "flag" : "1",
      "businessId" : 301,
      "username" : "file2",
      "nickName" : "测试文件流2",
      "name" : "测试文件流2",
      "fileSize": 1024,
      "holder":"admin",
      "createDate": "2024-10-24 10:04:04",
      "updateDate": "2024-10-24 10:04:04",
      "institutionId" : 105,
      "institutionName" : "财务部门",
      "menuList" : [ ]
    },
    {
      "delFlag" : "0",
      "flag" : "1",
      "businessId" : 302,
      "username" : "file3",
      "nickName" : "测试文件流3",
      "name" : "测试文件流3",
      "fileSize": 1024,
      "holder":"admin",
      "createDate": "2024-10-24 10:04:04",
      "updateDate": "2024-10-24 10:04:04",
      "institutionId" : 105,
      "institutionName" : "财务部门",
      "menuList" : [ ]
    },
    {
      "delFlag" : "0",
      "flag" : "1",
      "businessId" : 303,
      "username" : "file4",
      "nickName" : "测试文件流4",
      "name" : "测试文件流4",
      "fileSize": 1024,
      "holder":"admin",
      "createDate": "2024-10-24 10:04:04",
      "updateDate": "2024-10-24 10:04:04",
      "institutionId" : 105,
      "institutionName" : "财务部门",
      "menuList" : [ ]
    },

];

/**版本管理列表 数据*/
export const versionData: any[] = [
  {
    "versionId":"1",
    "versionName":"V1",
    "submitBy":"admin",
    "submitDate":"2021/11/15 18:55:06",
    "remarks":"STANDARD_BASIC添加发布的第一个版"
  },
  {
    "versionId":"2",
    "versionName":"V2",
    "submitBy":"admin",
    "submitDate":"2021/11/11 18:55:06",
    "remarks":"STANDARD_BASIC添加发布的第二个版"
  },
  {
    "versionId":"3",
    "versionName":"V3",
    "submitBy":"admin",
    "submitDate":"2021/11/11 18:55:06",
    "remarks":"标准导入"
  },
];


/**首页 新增表单树 数据*/
export const treeDataListTwo = [
  {
    label: '默认工作组',
    businessId: 1,
    children: [
      { label: '默认工作组01', businessId: 2 },
      { label: '默认工作组02', businessId: 3 },
      { label: '默认工作组03', businessId: 4 },
      { label: '默认工作组04', businessId: 5 },
    ],
  },
]


/**编辑页 选择字典树 数据*/
export const chooseDictoryTreeData = [
  {
    "delFlag" : "0",
    "flag" : "1",
    "businessId" : 100,
    "basicStandardName" : "所有命名字典",
    "anotherName":"所有命名字典",
    "parentId" : 0,
    "ancestors" : "0",
    "orderNum" : 0,
    "children" : [ ],
    icon: 'ion:settings-outline',
  },
  {
    "delFlag" : "0",
    "flag" : "1",
    "businessId" : 101,
    "basicStandardName" : "共享工作区",
    "anotherName":"共享工作区",
    "parentId" : 100,
    "ancestors" : "0,100",
    "children" : [ ],
    icon: 'ion:settings-outline',
  },
  {
    "delFlag" : "0",
    "flag" : "1",
    "businessId" : 102,
    "basicStandardName" : "关联域",
    "anotherName":"关联域",
    "parentId" : 101,
    "ancestors" : "0,100,101",
    "children" : [ ],
    icon: 'ion:settings-outline',
  },
  {
    "delFlag" : "0",
    "flag" : "1",
    "businessId" : 103,
    "basicStandardName" : "日期",
    "anotherName":"日期",
    "parentId" : 102,
    "ancestors" : "0,100,101,102",
    "children" : [ ],
    icon: 'ion:settings-outline',
  },
  {
    "delFlag" : "0",
    "flag" : "1",
    "businessId" : 104,
    "basicStandardName" : "创建日期",
    "anotherName":"创建日期",
    "parentId" : 102,
    "ancestors" : "0,100,101,102",
    "children" : [ ],
    icon: 'ion:settings-outline',
  },
]

/**对比左侧数据*/
export const leftContrastData: any[] = [
  {
    "businessId": 201,
    "standardChineseName": "对外投资出资方式",
    "anotherName": "对外投资出资方式",
    "parentId": 102,
    "publishStatus": "已发布",
    "businessDefinition": "对外投资出资方式",
    "standardCode": "BAS000004",
    "standardPath":'/公共代码/个人工作区/对外投资出资方式',
    "referenceStandard":[
      { icon: '🌐🔍', text: '数据源1' },
    ],
    "ancestors": "0,100,102",
    "location": "/基础标准/个人工作区/对外投资出资方式",
    "holderGroup": "个人工作区",
    "createDate": "2024-10-22 8:04:04",
    "updateDate": "2024-10-22 8:04:04",
    "icon": "ant-design:partition-outlined",
    "businessAttribute": "财务",
    "standardNumber": "BAS-004",
    "standardEnglishName": "Investment Contribution Method",
    "standardAlias": "Investment Contribution Method",
    "standardSource": "国家标准化管理委员会1",
    "definitionBasis": "相关法律法规",
    "businessRule": "对外投资的出资方式必须明确记录。",
    "dataType": "1",
    "tecDataType": "varchar",
    "valueRange": "非空字符串",
    "codeNumber": "CODE-201",
    "adaptability": "1",
    "technicalAttribute": "通用技术属性",
    "dataDisplay": "文本显示",
    "dataPrecision": "无",
    "dataLength": "255",
    "measurementUnit": "无",
    "managementAttribute": "通用管理属性",
    "creator": "王五",
    "updater": "赵六",
    "secondaryAuthorityDepartment": "技术部",
    "tertiaryAuthorityDepartment": "运维组",
    "coreSystem": "核心系统B",
    "dataStandardStatus": "有效",
    "expirationDate": "2025-10-24",
    "expirationReason": "无",
    "collaborativeDepartment": "人力资源部, 技术部"
  },
]
/**对比右侧数据*/
export const rightContrastData = [
  {
    "businessId": 201,
    "standardChineseName": "对外投资出资方式",
    "standardPath":'/公共代码/个人工作区/对外投资出资方式',
    "anotherName": "对外投资出资方式",
    "parentId": 102,
    "publishStatus": "已发布",
    "businessDefinition": "对外投资出资方式",
    "standardCode": "BAS000004",
    "referenceStandard":[
      { icon: '🌐🔍', text: '数据源1' },
    ],
    "ancestors": "0,100,102",
    "location": "/基础标准/个人工作区/对外投资出资方式",
    "holderGroup": "个人工作区",
    "createDate": "2024-10-22 8:04:04",
    "updateDate": "2024-10-22 8:04:04",
    "icon": "ant-design:partition-outlined",
    "businessAttribute": "财务",
    "standardNumber": "BAS-004",
    "standardEnglishName": "Investment Contribution Method",
    "standardAlias": "Investment Contribution Method",
    "standardSource": "国家标准化管理委员会2",
    "definitionBasis": "相关法律法规",
    "businessRule": "对外投资的出资方式必须明确记录。",
    "dataType": "1",
    "tecDataType": "varchar",
    "valueRange": "非空字符串",
    "codeNumber": "CODE-201",
    "adaptability": "1",
    "technicalAttribute": "通用技术属性",
    "dataDisplay": "文本显示",
    "dataPrecision": "无",
    "dataLength": "255",
    "measurementUnit": "无",
    "managementAttribute": "通用管理属性",
    "creator": "王五",
    "updater": "赵六",
    "secondaryAuthorityDepartment": "技术部",
    "tertiaryAuthorityDepartment": "运维组",
    "coreSystem": "核心系统B",
    "dataStandardStatus": "有效",
    "expirationDate": "2025-10-24",
    "expirationReason": "无",
    "collaborativeDepartment": "人力资源部, 技术部"
  },
]

/**对比左侧数据*/
export const leftContrastTableData = [
  {
    "businessId": 1,
    "codeValue": "00",
    "codeMeaning": "未填写",
    "description": '-',
    "updateBy": "DMP_admin",
    "updateDate": "2024-05-31 17:11:50",
  },
  {
    "businessId": 2,
    "codeValue": "01",
    "codeMeaning": "男性",
    "description": '-',
    "updateBy": "DMP_admin",
    "updateDate": "2024-05-31 17:11:50",
  },
  {
    "businessId": 3,
    "codeValue": "02",
    "codeMeaning": "女性",
    "description": '-',
    "updateBy": "DMP_admin",
    "updateDate": "2024-05-31 17:11:50",
  },
]
/**对比右侧数据*/
export const rightContrastTableData = [
  {
    "businessId": 1,
    "codeValue": "00",
    "codeMeaning": "未填写",
    "description": '-',
    "updateBy": "DMP_admin",
    "updateDate": "2024-05-31 17:11:50",
  },
  {
    "businessId": 2,
    "codeValue": "01",
    "codeMeaning": "男性",
    "description": '-',
    "updateBy": "DMP_admin",
    "updateDate": "2024-05-31 17:11:50",
  },
  {
    "businessId": 3,
    "codeValue": "02",
    "codeMeaning": "女性",
    "description": '-',
    "updateBy": "DMP_admin",
    "updateDate": "2024-05-31 17:11:50",
  },
]

/**关联关系 表格3 数据*/
export const relatedRelationshipsData3 = [
  {
    businessId: '1',
    standardName: '当前就读学校',
    standardNumber: 'BIDQ000000001',
    path: '/基础标准/DMP_admin-个人工作区/...',
    associationRelation:'无',
    associationDescription: '无',
    associationTime: '2024-01-01 10:00:00',
    operatorUser: 'DMP_admin',
  },
]


/**详情 表格 数据*/
export const detailData = [
  {
    codeValue: '00',
    codeMeaning: '代码1',
    description: '-',
    updateBy: 'gov_user01',
    updateDate:'2024-05-23 14:35:10',
    sourceSystemCodeValue: '-',
  },
  {
    codeValue: '01',
    codeMeaning: '代码2',
    description: '-',
    updateBy: 'gov_user01',
    updateDate:'2024-05-23 14:35:10',
    sourceSystemCodeValue: '-',
  },
  {
    codeValue: '02',
    codeMeaning: '代码3',
    description: '-',
    updateBy: 'gov_user01',
    updateDate:'2024-05-23 14:35:10',
    sourceSystemCodeValue: '-',
  },
  {
    codeValue: '03',
    codeMeaning: '代码4',
    description: '-',
    updateBy: 'gov_user01',
    updateDate:'2024-05-23 14:35:10',
    sourceSystemCodeValue: '-',
  },
  {
    codeValue: '04',
    codeMeaning: '代码5',
    description: '-',
    updateBy: 'gov_user01',
    updateDate:'2024-05-23 14:35:10',
    sourceSystemCodeValue: '-',
  },
]

/**编辑公共代码 列表数据*/
export const addValueData = [
  {
    sourceSystem: '系统1',
    sourceSystemCodeValue: '00',
  },
  {
    sourceSystem: '系统2',
    sourceSystemCodeValue: '01',
  },
  {
    sourceSystem: '系统3',
    sourceSystemCodeValue: '02',
  },
]
